@@ -237,3 +237,14 @@ class FlaviusPickupTime(FlaviusBase):
                                                 create_url=conf.FLAVIUS_API_PICKUP_TIME_REGIST,
                                                 update_url=conf.FLAVIUS_API_PICKUP_TIME_REGIST,
                                                 delete_url=conf.FLAVIUS_API_PICKUP_TIME_DELETE)
+
+
+class FlaviusHeaderExtPickup(FlaviusBase):
+    """
+    Flaviusの商品受け渡し情報(伝票ヘッダー拡張)を操作するAPI
+    """
+    def __init__(self):
+        super(FlaviusHeaderExtPickup, self).__init__(search_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_LIST,
+                                                     create_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_LIST,
+                                                     update_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_LIST,
+                                                     delete_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_DELETE)
